import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { createRequestOption } from 'app/core/request/request-util';
import { SearchWithPagination, Search } from 'app/core/request/request.model';
import { IUserWatchList } from 'app/shared/model/user-watch-list.model';
import { SearchResultsDTO } from 'app/shared/model/search/search-results-dto.model';

type EntityResponseType = HttpResponse<IUserWatchList>;
type EntityArrayResponseType = HttpResponse<IUserWatchList[]>;

@Injectable({ providedIn: 'root' })
export class UserWatchListService {
  public resourceUrl = this.applicationConfigService.getEndpointFor('api/user-watch-lists');
  public currentUserResourceUrl = this.applicationConfigService.getEndpointFor('api/currentuser-watch-lists');
  public resourceSearchUrl = this.applicationConfigService.getEndpointFor('api/_search/user-watch-lists');
  public currentUserResourceSearchUrl = this.applicationConfigService.getEndpointFor('api/_search/currentuser-watch-lists');

  constructor(protected http: HttpClient, private applicationConfigService: ApplicationConfigService) {}

  create(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.post<IUserWatchList>(this.resourceUrl, userWatchList, { observe: 'response' });
  }

  createForCurrentUser(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.post<IUserWatchList>(this.currentUserResourceUrl, userWatchList, { observe: 'response' });
  }

  update(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.put<IUserWatchList>(this.resourceUrl, userWatchList, { observe: 'response' });
  }

  find(id: number): Observable<EntityResponseType> {
    return this.http.get<IUserWatchList>(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  /** returns the watchlists of the current user */
  findMyWatchlists(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.currentUserResourceUrl, { params: options, observe: 'response' });
  }

  findExercises(watchlist: IUserWatchList, page: number): Observable<SearchResultsDTO> {
    return this.http.post<SearchResultsDTO>(`${this.currentUserResourceUrl}/${watchlist.id || ""}`, page);
  }

  query(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.resourceUrl, { params: options, observe: 'response' });
  }

  delete(id: number): Observable<HttpResponse<{}>> {
    return this.http.delete(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  search(req: Search): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.resourceSearchUrl, { params: options, observe: 'response' });
  }

  searchForCurrentUser(req: SearchWithPagination): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.currentUserResourceSearchUrl, { params: options, observe: 'response' });
  }
}
